require 'puppet/face'
require 'puppet/cloudpack/vmware'

Puppet::Face.define(:node_vmware, '0.0.1') do
  action :stop do
    summary "Stop a running virtual machine"
    description <<-'EOT'
      This action stops a running virtual machine.  By default, the guest
      operating system will be gracefully shut down using VMware Tools.
    EOT

    returns "Hash containing the VM's status"

    examples <<-'EOT'
      $ puppet node_vmware stop /Datacenters/MyDC/vm/jefftest --force
    EOT

    arguments "<path>"

    option '--force' do
      summary 'Forcibly power off the VM'
      description <<-'EOT'
        Forcibly power off the virtual machine without giving the guest
        operating system a chance to gracefully shut down.
      EOT
    end

    Puppet::CloudPack::VMware.add_timeout_option(self)

    when_invoked do |path, options|
      options[:path] = path
      Puppet::CloudPack::VMware.stop(options)
    end
  end
end
